@@ -321,10 +321,11 @@ GenPheno <- function(
 #' Data Generating Process
 #' 
 #' Generate a data set consisting of: \itemize{
-#' \item{"anno"}{A SNP-length annotation vector.}
-#' \item{"covar"}{A subject by 6 covariate matrix.}
-#' \item{"geno"}{A subject by SNP genotype matrix.}
-#' \item{"pheno"}{A subject-length phenotype vector.}
+#' \item{anno: (snps x 1) annotation vector.}
+#' \item{covar: (subjects x 6) covariate matrix.}
+#' \item{geno: (subjects x snps) genotype matrix.}
+#' \item{pheno: (subjects x 1) phenotype vector.}
+#' \item{type: Either "binary" or "quantitative".}
 #' }
 #'
 #' @param anno Annotation vector, if providing genotypes. Should match the
@@ -458,11 +459,17 @@ DGP <- function(
   )
 
   # Output.
+  if (binary) {
+    type <- "binary"
+  } else {
+    type <- "quantitative"
+  }
   out <- list(
     anno = anno_geno$anno,
     covar = covar,
     geno = anno_geno$geno,
-    pheno = pheno
+    pheno = pheno,
+    type = type
   )
   return(out)
 }
